@@ -1,38 +1,57 @@
 ### R code from vignette source 'ggenealogy.Rnw'
-### Encoding: UTF-8
 
 ###################################################
-### code chunk number 1: ggenealogy.Rnw:55-56
+### code chunk number 1: ggenealogy.Rnw:35-39
 ###################################################
-rm(list=ls())
+library(knitr)
+opts_chunk$set(
+concordance=TRUE
+)
 
 
 ###################################################
-### code chunk number 2: ggenealogy.Rnw:83-84 (eval = FALSE)
+### code chunk number 2: Roptions
+###################################################
+options(width = 60)
+options(SweaveHooks = list(fig = function() par(mar=c(3,3,1,0.5),mgp = c(2,1,0))))
+
+
+###################################################
+### code chunk number 3: ggenealogy.Rnw:47-52
+###################################################
+my.Swd <- function(name, width, height, ...)
+ grDevices::cairo_pdf(
+  filename = paste(name, "pdf", sep = "."),
+  width = width, height = height
+ )
+
+
+###################################################
+### code chunk number 4: ggenealogy.Rnw:90-91 (eval = FALSE)
 ###################################################
 ## install.packages("ggenealogy")
 
 
 ###################################################
-### code chunk number 3: ggenealogy.Rnw:90-91
+### code chunk number 5: ggenealogy.Rnw:97-98
 ###################################################
 library(ggenealogy)
 
 
 ###################################################
-### code chunk number 4: ggenealogy.Rnw:96-97 (eval = FALSE)
+### code chunk number 6: ggenealogy.Rnw:103-104 (eval = FALSE)
 ###################################################
 ## help(package="ggenealogy")
 
 
 ###################################################
-### code chunk number 5: ggenealogy.Rnw:102-103 (eval = FALSE)
+### code chunk number 7: ggenealogy.Rnw:109-110 (eval = FALSE)
 ###################################################
 ## help(getChild)
 
 
 ###################################################
-### code chunk number 6: ggenealogy.Rnw:108-111 (eval = FALSE)
+### code chunk number 8: ggenealogy.Rnw:115-118 (eval = FALSE)
 ###################################################
 ## data(sbGeneal)
 ## getChild("Tokyo", sbGeneal)
@@ -40,7 +59,7 @@ library(ggenealogy)
 
 
 ###################################################
-### code chunk number 7: ggenealogy.Rnw:118-122
+### code chunk number 9: ggenealogy.Rnw:125-129
 ###################################################
 data(sbGeneal)
 head(sbGeneal)
@@ -49,41 +68,41 @@ str(sbGeneal)
 
 
 ###################################################
-### code chunk number 8: ggenealogy.Rnw:129-130
+### code chunk number 10: ggenealogy.Rnw:136-137 (eval = FALSE)
 ###################################################
-help(dfToIG)
+## help(dfToIG)
 
 
 ###################################################
-### code chunk number 9: ggenealogy.Rnw:137-139
+### code chunk number 11: ggenealogy.Rnw:144-146
 ###################################################
 ig <- dfToIG(sbGeneal)
 class(ig)
 
 
 ###################################################
-### code chunk number 10: ggenealogy.Rnw:152-154
+### code chunk number 12: ggenealogy.Rnw:159-161
 ###################################################
 isParent("Young","Essex",sbGeneal)
 isParent("Essex","Young",sbGeneal)
 
 
 ###################################################
-### code chunk number 11: ggenealogy.Rnw:159-161
+### code chunk number 13: ggenealogy.Rnw:166-168
 ###################################################
 isChild("Young","Essex",sbGeneal)
 isChild("Essex","Young",sbGeneal)
 
 
 ###################################################
-### code chunk number 12: ggenealogy.Rnw:166-168
+### code chunk number 14: ggenealogy.Rnw:173-175
 ###################################################
 getVariable("Young", sbGeneal, "devYear")
 getVariable("Essex", sbGeneal, "devYear")
 
 
 ###################################################
-### code chunk number 13: ggenealogy.Rnw:173-176
+### code chunk number 15: ggenealogy.Rnw:180-183
 ###################################################
 getParent("Young",sbGeneal)
 getParent("Tokyo",sbGeneal)
@@ -91,39 +110,39 @@ getVariable("Tokyo", sbGeneal,"devYear")
 
 
 ###################################################
-### code chunk number 14: ggenealogy.Rnw:181-183
+### code chunk number 16: ggenealogy.Rnw:188-190
 ###################################################
 getChild("Tokyo",sbGeneal)
 getChild("Ogden",sbGeneal)
 
 
 ###################################################
-### code chunk number 15: ggenealogy.Rnw:192-193
+### code chunk number 17: ggenealogy.Rnw:199-200
 ###################################################
 getAncestors("Young",sbGeneal,1)
 
 
 ###################################################
-### code chunk number 16: ggenealogy.Rnw:198-200
+### code chunk number 18: ggenealogy.Rnw:205-207
 ###################################################
 getAncestors("Young",sbGeneal,5)
 nrow(getAncestors("Young",sbGeneal,5))
 
 
 ###################################################
-### code chunk number 17: ggenealogy.Rnw:207-208
+### code chunk number 19: ggenealogy.Rnw:214-215
 ###################################################
 getDescendants("Ogden",sbGeneal,1)
 
 
 ###################################################
-### code chunk number 18: ggenealogy.Rnw:213-214
+### code chunk number 20: ggenealogy.Rnw:220-221
 ###################################################
 getDescendants("Ogden",sbGeneal,2)
 
 
 ###################################################
-### code chunk number 19: ggenealogy.Rnw:221-225
+### code chunk number 21: ggenealogy.Rnw:228-232
 ###################################################
 nr = nrow(sbGeneal)
 listInd = sbGeneal[(nr-3):nr,]$child
@@ -132,27 +151,27 @@ listAnc
 
 
 ###################################################
-### code chunk number 20: ggenealogy.Rnw:230-232
+### code chunk number 22: ggenealogy.Rnw:237-239
 ###################################################
 listAnc = sapply(listInd, function(x) getAncestors(x, sbGeneal, 5), simplify=F)
 listAnc
 
 
 ###################################################
-### code chunk number 21: ggenealogy.Rnw:239-241
+### code chunk number 23: ggenealogy.Rnw:246-248
 ###################################################
 getDegree("Tokyo", "Ogden", ig, sbGeneal)
 getDegree("Tokyo", "Holladay", ig, sbGeneal)
 
 
 ###################################################
-### code chunk number 22: ggenealogy.Rnw:252-253
+### code chunk number 24: ggenealogy.Rnw:259-260
 ###################################################
 getBasicStatistics(ig)
 
 
 ###################################################
-### code chunk number 23: ggenealogy.Rnw:260-263
+### code chunk number 25: ggenealogy.Rnw:267-270
 ###################################################
 eList = getEdges(ig, sbGeneal)
 head(eList)
@@ -160,7 +179,7 @@ nrow(eList)
 
 
 ###################################################
-### code chunk number 24: ggenealogy.Rnw:268-271
+### code chunk number 26: ggenealogy.Rnw:275-278
 ###################################################
 nList = getNodes(sbGeneal)
 head(nList)
@@ -168,120 +187,120 @@ length(nList)
 
 
 ###################################################
-### code chunk number 25: plotAncDes1
+### code chunk number 27: plotAncDes1
 ###################################################
 plotAncDes("Lee", sbGeneal,5,4)
 
 
 ###################################################
-### code chunk number 26: plotAncDes1
+### code chunk number 28: plotAncDes1-1
 ###################################################
 plotAncDes("Lee", sbGeneal,5,4)
 
 
 ###################################################
-### code chunk number 27: plotAncDes2
+### code chunk number 29: plotAncDes2
 ###################################################
 plotAncDes("Tokyo", sbGeneal, vColor = "blue") + ggplot2::labs(
   x="Generation index",y="")
 
 
 ###################################################
-### code chunk number 28: plotAncDes2
+### code chunk number 30: plotAncDes2-1
 ###################################################
 plotAncDes("Tokyo", sbGeneal, vColor = "blue") + ggplot2::labs(
   x="Generation index",y="")
 
 
 ###################################################
-### code chunk number 29: ggenealogy.Rnw:335-336
+### code chunk number 31: ggenealogy.Rnw:342-343
 ###################################################
 getPath("Brim", "Bedford", sbIG, sbGeneal, "devYear", isDirected = FALSE)
 
 
 ###################################################
-### code chunk number 30: ggenealogy.Rnw:341-343 (eval = FALSE)
+### code chunk number 32: ggenealogy.Rnw:348-350 (eval = FALSE)
 ###################################################
 ## dirIG = dfToIG(sbGeneal, isDirected = TRUE)
 ## getPath("Brim", "Bedford", dirIG, sbGeneal, "devYear", isDirected = TRUE)
 
 
 ###################################################
-### code chunk number 31: ggenealogy.Rnw:348-349 (eval = FALSE)
+### code chunk number 33: ggenealogy.Rnw:355-356 (eval = FALSE)
 ###################################################
 ## getPath("Bedford", "Brim", dirIG, sbGeneal, "devYear", isDirected=TRUE)
 
 
 ###################################################
-### code chunk number 32: ggenealogy.Rnw:356-357
+### code chunk number 34: ggenealogy.Rnw:363-364
 ###################################################
 pathBB = getPath("Bedford","Brim", ig, sbGeneal, "devYear", isDirected=FALSE)
 
 
 ###################################################
-### code chunk number 33: plotPath1
+### code chunk number 35: plotPath
 ###################################################
 plotPath(pathBB, sbGeneal, "devYear")
 
 
 ###################################################
-### code chunk number 34: plotPath1
+### code chunk number 36: plotPath-1
 ###################################################
 plotPath(pathBB, sbGeneal, "devYear")
 
 
 ###################################################
-### code chunk number 35: plotPath1a
+### code chunk number 37: plotPath1
 ###################################################
 plotPath(pathBB, sbGeneal, "devYear") + ggplot2::xlab("Year")
 
 
 ###################################################
-### code chunk number 36: plotPath1a
+### code chunk number 38: plotPath1-1
 ###################################################
 plotPath(pathBB, sbGeneal, "devYear") + ggplot2::xlab("Year")
 
 
 ###################################################
-### code chunk number 37: plotPath2
+### code chunk number 39: plotPath2
 ###################################################
 pathNT = getPath("Narow", "Tokyo", ig, sbGeneal, "devYear", isDirected=FALSE)
 plotPath(pathNT, sbGeneal, "devYear")
 
 
 ###################################################
-### code chunk number 38: plotPath2
+### code chunk number 40: plotPath2-1
 ###################################################
 pathNT = getPath("Narow", "Tokyo", ig, sbGeneal, "devYear", isDirected=FALSE)
 plotPath(pathNT, sbGeneal, "devYear")
 
 
 ###################################################
-### code chunk number 39: plotPathOnAll1
+### code chunk number 41: plotPathOnAll1
 ###################################################
 plotPathOnAll(pathNT, sbGeneal, ig, "devYear", bin = 3)
 
 
 ###################################################
-### code chunk number 40: plotPathOnAll1
+### code chunk number 42: plotPathOnAll1-1
 ###################################################
 plotPathOnAll(pathNT, sbGeneal, ig, "devYear", bin = 3)
 
 
 ###################################################
-### code chunk number 41: plotPathOnAll2
+### code chunk number 43: plotPathOnAll2
 ###################################################
 plotPathOnAll(pathNT, sbGeneal, ig, "devYear", bin = 6) + ggplot2::xlab("Year")
 
 
 ###################################################
-### code chunk number 42: plotPathOnAll2
+### code chunk number 44: plotPathOnAll2-1
 ###################################################
 plotPathOnAll(pathNT, sbGeneal, ig, "devYear", bin = 6) + ggplot2::xlab("Year")
 
 
 ###################################################
-### code chunk number 43: plotDegMatrix1
+### code chunk number 45: plotDegMatrix1
 ###################################################
 varieties=c("Brim", "Bedford", "Calland", "Narow", "Pella", "Tokyo", "Young", "Zane")
 p = plotDegMatrix(varieties, ig, sbGeneal)
@@ -291,7 +310,7 @@ p + ggplot2::scale_fill_continuous(low = "white", high = "darkgreen") +
 
 
 ###################################################
-### code chunk number 44: plotDegMatrix1
+### code chunk number 46: plotDegMatrix1-1
 ###################################################
 varieties=c("Brim", "Bedford", "Calland", "Narow", "Pella", "Tokyo", "Young", "Zane")
 p = plotDegMatrix(varieties, ig, sbGeneal)
@@ -301,27 +320,27 @@ p + ggplot2::scale_fill_continuous(low = "white", high = "darkgreen") +
 
 
 ###################################################
-### code chunk number 45: ggenealogy.Rnw:508-509
+### code chunk number 47: ggenealogy.Rnw:515-516
 ###################################################
 getDegree("Bedford", "Zane", ig, sbGeneal)
 
 
 ###################################################
-### code chunk number 46: plotYearMatrix1
+### code chunk number 48: plotYearMatrix1
 ###################################################
 varieties=c("Brim", "Bedford", "Calland", "Narow", "Pella", "Tokyo", "Young", "Zane")
 plotDegMatrix(varieties, ig, sbGeneal)
 
 
 ###################################################
-### code chunk number 47: plotYearMatrix1
+### code chunk number 49: plotYearMatrix1-1
 ###################################################
 varieties=c("Brim", "Bedford", "Calland", "Narow", "Pella", "Tokyo", "Young", "Zane")
 plotDegMatrix(varieties, ig, sbGeneal)
 
 
 ###################################################
-### code chunk number 48: ggenealogy.Rnw:540-543
+### code chunk number 50: ggenealogy.Rnw:547-550
 ###################################################
 data("statGeneal")
 dim(statGeneal)
@@ -329,7 +348,7 @@ colnames(statGeneal)
 
 
 ###################################################
-### code chunk number 49: ggenealogy.Rnw:552-557
+### code chunk number 51: ggenealogy.Rnw:559-564
 ###################################################
 indVec <- getNodes(statGeneal)
 indVec <- indVec[which(indVec != "", )]
@@ -339,26 +358,26 @@ table(numDesc)
 
 
 ###################################################
-### code chunk number 50: ggenealogy.Rnw:560-561
+### code chunk number 52: ggenealogy.Rnw:567-568
 ###################################################
 which(numDesc == 159)
 
 
 ###################################################
-### code chunk number 51: ggenealogy.Rnw:566-567 (eval = FALSE)
+### code chunk number 53: ggenealogy.Rnw:573-574 (eval = FALSE)
 ###################################################
 ## plotAncDes("David Cox", statGeneal, mAnc = 6, mDes = 6, vCol = "blue")
 
 
 ###################################################
-### code chunk number 52: ggenealogy.Rnw:579-581
+### code chunk number 54: ggenealogy.Rnw:586-588
 ###################################################
 length(getChild("Peter Bloomfield", statGeneal))
 nrow(getDescendants("Peter Bloomfield", statGeneal, gen = 100))
 
 
 ###################################################
-### code chunk number 53: pathCB
+### code chunk number 55: pathCB
 ###################################################
 statIG <- dfToIG(statGeneal)
 pathCB <- getPath("David Cox", "Petra Buzkova", statIG, statGeneal, "gradYear", isDirected = FALSE)
@@ -367,7 +386,7 @@ plotPath(pathCB, statGeneal, "gradYear", fontFace = 4) + ggplot2::theme(axis.tex
 
 
 ###################################################
-### code chunk number 54: pathCB
+### code chunk number 56: pathCB-1
 ###################################################
 statIG <- dfToIG(statGeneal)
 pathCB <- getPath("David Cox", "Petra Buzkova", statIG, statGeneal, "gradYear", isDirected = FALSE)
@@ -376,24 +395,27 @@ plotPath(pathCB, statGeneal, "gradYear", fontFace = 4) + ggplot2::theme(axis.tex
 
 
 ###################################################
-### code chunk number 55: plotCBText
+### code chunk number 57: plotCBText
 ###################################################
+getOption("SweaveHooks")[["fig"]]()
 plotPathOnAll(pathCB, statGeneal, statIG, "gradYear", bin = 200) +
    ggplot2::theme(axis.text = ggplot2::element_text(size = 8), axis.title =
    ggplot2::element_text(size = 8)) + ggplot2::scale_x_continuous(expand = c(.1, .2))
 
 
 ###################################################
-### code chunk number 56: plotCBText
+### code chunk number 58: plotCBText-1
 ###################################################
+getOption("SweaveHooks")[["fig"]]()
 plotPathOnAll(pathCB, statGeneal, statIG, "gradYear", bin = 200) +
    ggplot2::theme(axis.text = ggplot2::element_text(size = 8), axis.title =
    ggplot2::element_text(size = 8)) + ggplot2::scale_x_continuous(expand = c(.1, .2))
 
 
 ###################################################
-### code chunk number 57: plotCBNoText
+### code chunk number 59: plotCBNoText
 ###################################################
+getOption("SweaveHooks")[["fig"]]()
 plotPathOnAll(pathCB, statGeneal, statIG, "gradYear", bin = 200, nodeSize = .5,
    pathNodeSize = 2.5, nodeCol = "darkgray", edgeCol = "lightgray") +
    ggplot2::theme(axis.text = ggplot2::element_text(size = 8), axis.title =
@@ -401,8 +423,9 @@ plotPathOnAll(pathCB, statGeneal, statIG, "gradYear", bin = 200, nodeSize = .5,
 
 
 ###################################################
-### code chunk number 58: plotCBNoText
+### code chunk number 60: plotCBNoText-1
 ###################################################
+getOption("SweaveHooks")[["fig"]]()
 plotPathOnAll(pathCB, statGeneal, statIG, "gradYear", bin = 200, nodeSize = .5,
    pathNodeSize = 2.5, nodeCol = "darkgray", edgeCol = "lightgray") +
    ggplot2::theme(axis.text = ggplot2::element_text(size = 8), axis.title =
@@ -410,29 +433,30 @@ plotPathOnAll(pathCB, statGeneal, statIG, "gradYear", bin = 200, nodeSize = .5,
 
 
 ###################################################
-### code chunk number 59: plotAnimate (eval = FALSE)
+### code chunk number 61: plotAnimate (eval = FALSE)
 ###################################################
+getOption("SweaveHooks")[["fig"]]()
 ## plotPathOnAll(pathCB, statGeneal, statIG, "gradYear", bin = 200, nodeSize = .5,
 ##    pathNodeSize = 2.5, nodeCol = "darkgray", edgeCol = "lightgray", animate =
 ##    TRUE)
 
 
 ###################################################
-### code chunk number 60: ggenealogy.Rnw:669-671
+### code chunk number 62: ggenealogy.Rnw:690-692
 ###################################################
 AKBranchYield <- getBranchQuant("A.K.", sbGeneal, "yield", 15)
 dplyr::select(AKBranchYield, -DesNames)
 
 
 ###################################################
-### code chunk number 61: ggenealogy.Rnw:678-680
+### code chunk number 63: ggenealogy.Rnw:699-701
 ###################################################
 CoxBranchYear <- getBranchQuant("David Cox", statGeneal, "gradYear", 15)
 head(dplyr::select(CoxBranchYear, -DesNames), 10)
 
 
 ###################################################
-### code chunk number 62: ggenealogy.Rnw:691-695
+### code chunk number 64: ggenealogy.Rnw:712-716
 ###################################################
 v1 = "David Cox"; geneal = statGeneal; colName = "thesis"; gen = 15
 rExpr = "grepl('(?i)Stochastic', geneal$colName)"
@@ -441,7 +465,7 @@ head(dplyr::select(CoxBranchStochastic, -DesNames))
 
 
 ###################################################
-### code chunk number 63: ggenealogy.Rnw:706-709
+### code chunk number 65: ggenealogy.Rnw:727-730
 ###################################################
 desDC <- getDescendants("David Cox", statGeneal, 15)
 tableDC <- table(statGeneal[match(desDC$label, statGeneal$child), ]$school)
@@ -449,7 +473,7 @@ tail(sort(tableDC), 5)
 
 
 ###################################################
-### code chunk number 64: ggenealogy.Rnw:714-718
+### code chunk number 66: ggenealogy.Rnw:735-739
 ###################################################
 colName = "school"
 rExpr = "geneal$colName=='University of London'"
@@ -458,7 +482,7 @@ head(dplyr::select(DCBranchUL, -DesNames))
 
 
 ###################################################
-### code chunk number 65: ggenealogy.Rnw:723-725
+### code chunk number 67: ggenealogy.Rnw:744-746
 ###################################################
 DCChild <- statGeneal[match(getChild("David Cox", statGeneal), statGeneal$child), ]
 sum(DCChild$school == "University of London")
